%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 01/02/2024
\ProvidesFile{ecves.def}[europecv Spanish definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Informaci\'on personal}}
\def\ecv@datekey{\ecv@utf{Actualizado el\\}}
\def\ecv@namekey{\ecv@utf{Nombre(s)~/ Apellido(s)}}
\def\ecv@addresskey{\ecv@utf{Direcci\'on(es)}}
\def\ecv@telkey{\ecv@utf{Tel\'efono(s)}}
\def\ecv@mobilekey{\ecv@utf{M\'ovil}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@officekey{\ecv@utf{Oficina}}
\def\ecv@emailkey{\ecv@utf{Correo(s) electr\'onico(s)}}
\def\ecv@professionalkey{\ecv@utf{Correo(s) electr\'onico(s)} de trabajo}
\def\ecv@skypekey{\ecv@utf{Skype}}
\def\ecv@matrixriotkey{\ecv@utf{Matrix/Riot}}
\def\ecv@youtubekey{\ecv@utf{YouTube}}
\def\ecv@peckey{\ecv@utf{PEC}}
\def\ecv@homepagekey{\ecv@utf{Home page}}
\def\ecv@nationalitykey{\ecv@utf{Nacionalidad(es)}}
\def\ecv@birthkey{\ecv@utf{Fecha de nacimiento}}
\def\ecv@genderkey{\ecv@utf{G\'enero}}
% Footer
\def\ecv@pagekey{\ecv@utf{P\'agina}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ de}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Lengua(s) materna(s)}}
\def\ecv@assesskey{\ecv@utf{Auto evaluaci\'on}}
\def\ecv@levelkey{\ecv@utf{Nivel europeo}}
\def\ecv@understandkey{\ecv@utf{Comprender}}
\def\ecv@speakkey{\ecv@utf{Hablar}}
\def\ecv@writekey{\ecv@utf{Escribir}}
\def\ecv@listenkey{\ecv@utf{Comprensi\'on auditiva}}
\def\ecv@readkey{\ecv@utf{Comprensi\'on de lectura}}
\def\ecv@interactkey{\ecv@utf{Interacci\'on oral}}
\def\ecv@productkey{\ecv@utf{Expresi\'on oral}}
\def\ecv@langfooterkey{\ecv@utf{Nivel del Marco Europeo Com\'un de Referencia \ecv@upshape{(}MECR\ecv@upshape{)}}}
\def\ecv@cefbasickey{\ecv@utf{Usuario b\'asico}}
\def\ecv@cefindepkey{\ecv@utf{Usuario independiente}}
\def\ecv@cefprofkey{\ecv@utf{Usuario competente}}

\renewcommand*{\ecvbranding}{\\[5pt]\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}}}
\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{C\ecv@kern u\ecv@kern r\ecv@kern r\ecv@kern i\ecv@kern c\ecv@kern u\ecv@kern l\ecv@kern u\ecv@kern m \ecv@kern v\ecv@kern i\ecv@kern t\ecv@kern a\ecv@kern e}}\ecvbranding}
